import javax.naming.*;
import javax.naming.directory.*;

import java.util.Hashtable;

/**
 * Demonstrates how to perform a search by specifying a search filter
 * and search controls, asking for the object of each entry to be returned.
 *
 * usage: java Search
 */
class Search {
    public static void printSearchEnumeration(NamingEnumeration enum) {
	try {
	    while (enum.hasMore()) {
		SearchResult sr = (SearchResult)enum.next();
		System.out.println(sr.getName() + ": " + 
		    sr.getClassName() + ": " + sr.getObject());
	    }
	} catch (NamingException e) {
	    e.printStackTrace();
	}
    }

    public static void main(String[] args) {

	// Set up environment for creating initial context
	Hashtable env = new Hashtable(11);
	env.put(Context.INITIAL_CONTEXT_FACTORY, 
	    "com.sun.jndi.ldap.LdapCtxFactory");
	env.put(Context.PROVIDER_URL, "ldap://localhost:389/o=JNDITutorial");

	// So that object factory can be found
	env.put(Context.OBJECT_FACTORIES, "DrinkFactory");

	try {
	    // Create initial context
	    DirContext ctx = new InitialDirContext(env);

	    SearchControls ctls = new SearchControls();
	    ctls.setReturningObjFlag(true);

	    // Specify the search filter to match any object
	    String filter = "(objectclass=*)";

	    // Search for objects using filter
	    NamingEnumeration answer = ctx.search("", filter, ctls);

	    // Print the answer
	    printSearchEnumeration(answer);
	} catch (Exception e) {
	    e.printStackTrace();
	}
    }
}
